@@ -72,6 +72,8 @@ void plist_json_set_debug(int debug)
 }
 
 #ifndef HAVE_STRNDUP
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wshadow"
 static char* strndup(const char* str, size_t len)
 {
     char *newstr = (char *)malloc(len+1);
@@ -81,6 +83,7 @@ static char* strndup(const char* str, size_t len)
     }
     return newstr;
 }
+#pragma GCC diagnostic pop
 #endif
 
 static size_t dtostr(char *buf, size_t bufsize, double realval)
@@ -107,7 +110,7 @@ static size_t dtostr(char *buf, size_t bufsize, double realval)
     return len;
 }
 
-static int node_to_json(node_t node, bytearray_t **outbuf, uint32_t depth, int prettify)
+static plist_err_t node_to_json(node_t node, bytearray_t **outbuf, uint32_t depth, int prettify)
 {
     plist_data_t node_data = NULL;
 
@@ -140,9 +143,9 @@ static int node_to_json(node_t node, bytearray_t **outbuf, uint32_t depth, int p
     case PLIST_INT:
         val = (char*)malloc(64);
         if (node_data->length == 16) {
-            val_len = snprintf(val, 64, "%"PRIu64, node_data->intval);
+            val_len = snprintf(val, 64, "%" PRIu64, node_data->intval);
         } else {
-            val_len = snprintf(val, 64, "%"PRIi64, node_data->intval);
+            val_len = snprintf(val, 64, "%" PRIi64, node_data->intval);
         }
         str_buf_append(*outbuf, val, val_len);
         free(val);
@@ -203,7 +206,7 @@ static int node_to_json(node_t node, bytearray_t **outbuf, uint32_t depth, int p
                     str_buf_append(*outbuf, "  ", 2);
                 }
             }
-            int res = node_to_json(ch, outbuf, depth+1, prettify);
+            plist_err_t res = node_to_json(ch, outbuf, depth+1, prettify);
             if (res < 0) {
                 return res;
             }
@@ -231,7 +234,7 @@ static int node_to_json(node_t node, bytearray_t **outbuf, uint32_t depth, int p
                     str_buf_append(*outbuf, "  ", 2);
                 }
             }
-            int res = node_to_json(ch, outbuf, depth+1, prettify);
+            plist_err_t res = node_to_json(ch, outbuf, depth+1, prettify);
             if (res < 0) {
                 return res;
             }
@@ -308,7 +311,7 @@ static int num_digits_u(uint64_t i)
     return n;
 }
 
-static int node_estimate_size(node_t node, uint64_t *size, uint32_t depth, int prettify)
+static plist_err_t node_estimate_size(node_t node, uint64_t *size, uint32_t depth, int prettify)
 {
     plist_data_t data;
     if (!node) {
@@ -319,7 +322,7 @@ static int node_estimate_size(node_t node, uint64_t *size, uint32_t depth, int p
         node_t ch;
         unsigned int n_children = node_n_children(node);
         for (ch = node_first_child(node); ch; ch = node_next_sibling(ch)) {
-            int res = node_estimate_size(ch, size, depth + 1, prettify);
+            plist_err_t res = node_estimate_size(ch, size, depth + 1, prettify);
             if (res < 0) {
                 return res;
             }
@@ -395,12 +398,12 @@ static int node_estimate_size(node_t node, uint64_t *size, uint32_t depth, int p
     return PLIST_ERR_SUCCESS;
 }
 
-PLIST_API int plist_to_json(plist_t plist, char **json, uint32_t* length, int prettify)
+plist_err_t plist_to_json(plist_t plist, char **plist_json, uint32_t* length, int prettify)
 {
     uint64_t size = 0;
-    int res;
+    plist_err_t res;
 
-    if (!plist || !json || !length) {
+    if (!plist || !plist_json || !length) {
         return PLIST_ERR_INVALID_ARG;
     }
 
@@ -409,7 +412,7 @@ PLIST_API int plist_to_json(plist_t plist, char **json, uint32_t* length, int pr
         return PLIST_ERR_FORMAT;
     }
 
-    res = node_estimate_size(plist, &size, 0, prettify);
+    res = node_estimate_size((node_t)plist, &size, 0, prettify);
     if (res < 0) {
         return res;
     }
@@ -420,10 +423,10 @@ PLIST_API int plist_to_json(plist_t plist, char **json, uint32_t* length, int pr
         return PLIST_ERR_NO_MEM;
     }
 
-    res = node_to_json(plist, &outbuf, 0, prettify);
+    res = node_to_json((node_t)plist, &outbuf, 0, prettify);
     if (res < 0) {
         str_buf_free(outbuf);
-        *json = NULL;
+        *plist_json = NULL;
         *length = 0;
         return res;
     }
@@ -433,7 +436,7 @@ PLIST_API int plist_to_json(plist_t plist, char **json, uint32_t* length, int pr
 
     str_buf_append(outbuf, "\0", 1);
 
-    *json = outbuf->data;
+    *plist_json = (char*)outbuf->data;
     *length = outbuf->len - 1;
 
     outbuf->data = NULL;
@@ -779,7 +782,7 @@ static plist_t parse_object(const char* js, jsmntok_info_t* ti, int* index)
     return obj;
 }
 
-PLIST_API int plist_from_json(const char *json, uint32_t length, plist_t * plist)
+plist_err_t plist_from_json(const char *json, uint32_t length, plist_t * plist)
 {
     if (!plist) {
         return PLIST_ERR_INVALID_ARG;
@@ -797,7 +800,7 @@ PLIST_API int plist_from_json(const char *json, uint32_t length, plist_t * plist
     jsmntok_t *tokens = NULL;
 
     do {
-        jsmntok_t* newtokens = realloc(tokens, sizeof(jsmntok_t)*maxtoks);
+        jsmntok_t* newtokens = (jsmntok_t*)realloc(tokens, sizeof(jsmntok_t)*maxtoks);
         if (!newtokens) {
             PLIST_JSON_ERR("%s: Out of memory\n", __func__);
             return PLIST_ERR_NO_MEM;
